/*
 * lodju.c - main program and user interface for image archive tool
 */


#include <stdlib.h>
#include <glade/glade.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk-pixbuf/gdk-pixbuf-loader.h>

#include "lodju.h"


static gint count_targets(const GtkTargetEntry *targets)
{
    gint n;
    
    for (n = 0; targets[n].target != NULL; ++n)
    	continue;
    return n;
}


static void drag_source_set(GtkWidget *widget, const GtkTargetEntry *targets)
{
    gtk_drag_source_set(widget,
    	    	    	GDK_BUTTON1_MASK,
			targets,
			count_targets(targets),
			GDK_ACTION_MOVE);
}


static void drag_dest_set(GtkWidget *widget, const GtkTargetEntry *targets)
{
    gtk_drag_dest_set(widget,
    	    	      GTK_DEST_DEFAULT_ALL,
		      targets,
		      count_targets(targets),
		      GDK_ACTION_MOVE);
}


/***********************************************************************
 * Main program.
 */


int main(int argc, char **argv)
{
    GladeXML *xml;
    static const GtkTargetEntry image_list_drag_targets[] = {
	{ "application/x-lodju-dnd-image", 0, MIME_LODJU_DND_IMAGE },
	{ NULL }
    };
    static const GtkTargetEntry folder_tree_source_drag_targets[] = {
	{ "application/x-lodju-dnd-folder", 0, MIME_LODJU_DND_FOLDER },
	{ NULL }
    };
    static const GtkTargetEntry folder_tree_dest_drag_targets[] = {
	{ "application/x-lodju-dnd-folder", 0, MIME_LODJU_DND_FOLDER },
	{ "application/x-lodju-dnd-image", 0, MIME_LODJU_DND_IMAGE },
	{ NULL }
    };

    gettext_init();
    gtk_init(&argc, &argv);
    
    if (argc > 1 && argv[1][0] == '-') {
	g_message("Lodju has no command line options, sorry.");
	return EXIT_FAILURE;
    }
    
    gdk_rgb_init();
    glade_init();
    
    cfg_load();
    
    xml = load_user_interface("lodju_window");
    if (xml == NULL)
	return EXIT_FAILURE;
    
    toplevel_set_widgets(xml);
    meta_set_widgets(xml);
    image_list_set(GTK_CLIST(glade_xml_get_widget(xml, "image_list")));
    folder_tree_set(GTK_CTREE(glade_xml_get_widget(xml, "folder_tree")));

    if (argc > 1)
    	open_image_database(argv[1]);
    else
    	open_image_database("default.lodju");

    drag_source_set(GTK_WIDGET(image_list_get()), image_list_drag_targets);
    drag_source_set(GTK_WIDGET(folder_tree_get()), 
    	    	    folder_tree_source_drag_targets);
    drag_dest_set(GTK_WIDGET(folder_tree_get()), 
    	    	  folder_tree_dest_drag_targets);

    gtk_main();
    
    close_image_database();

    return 0;
}
